<?php

/**
 * Administration settings form for defining sub-site field references. The
 * weight of the fields selected is used to detemind, which content types
 * (parents) should be associated with the different nodes.
 *
 * @param array $form_state
 * @return string
 */
function panels_subsites_ref_form(&$form_state) {

  // Check that content types have been selected.
  $content_types = array_filter(variable_get('panels_subsites_content_types', NULL));
  if (empty($content_types)) {
    drupal_set_message(t('You have not yet selected content types to associated with slugs. Click <a href="@link">here</a> to configure it.',
          array('@link' => url('admin/build/subsites'))));
    return;
  }

  // Add form style sheet.
  drupal_add_css(drupal_get_path('module', 'panels_subsites') . '/css/panels_subsites.css', 'module');

  // Find all node-reference fields.
  $fields = content_fields();
  $field_refs = array('none' => t('-- None --'));
  foreach ($fields as $field) {
    if ($field['type'] == 'nodereference') {
      $field_refs[$field['field_name']] = $field['field_name'];
    }
  }

  // Load all types.
  $types = node_get_types();

  // Convert selected content types into an array of user-friendly names.
  $content_type_options = array();
  foreach ($content_types as $key) {
    $content_type_options[$key] = $types[$key]->name;

   // Unset the selected content type from the list, as they are the ones
   // referenced.
   unset($types[$key]);
  }
  
  // Build fieldset for each content type
  foreach ($types as $nodetype => $obj) {
    $form['panels_subsites_content_type_' . $nodetype] = array(
      '#type' => 'fieldset',
      '#title' => $obj->name,
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );

    foreach (array_keys($content_type_options) as $key) {
      // Load default values for the current field.
      $result = db_query('SELECT *
                          FROM {panels_subsites_settings}
                          WHERE content_type = "%s"
                            AND nodetype = "%s"', $key, $nodetype);
      $record = db_fetch_array($result);

      // Add more informaion to the record.
      if (empty($record)) {
        $record = array();
      }
      $record['content_type'] = $key;
      $record['nodetype'] = $nodetype;
      $record['ref_options'] = $field_refs;
      $record['content_type_options'] = $content_type_options;
      
      // Build the form element.
      $form['panels_subsites_content_type_' . $nodetype][$key . '_' . $nodetype . '_ref'] = array(
        '#type' => 'panels_subsites_ref',
        '#value' => $record,
      );
    }
  }

  // Get sytemet form look and feel.
  $form['buttons']['submit'] = array('#type' => 'submit', '#value' => t('Save configuration') );
  $form['#theme'] = 'system_settings_form';
  
  return $form;
}

function panels_subsites_ref_form_submit($form, &$form_state) {
  // Exclude unnecessary elements from values.
  unset($form_state['values']['submit'], $form_state['values']['reset'], $form_state['values']['form_id'], $form_state['values']['op'], $form_state['values']['form_token'], $form_state['values']['form_build_id']);

  // Run through form values and save them
  foreach ($form_state['values'] as $key => $value) {
    // Check that a rule have been build, if not check next rule.
    if ($value['ref'] == 'none') {
      continue;
    }

    // If rule id is set, this is an update.
    if ($value['rid']) {
      $result = db_query('UPDATE {panels_subsites_settings}
                          SET content_type = "%s",
                              nodetype = "%s",
                              ref = "%s",
                              weight = %d
                          WHERE rid = %d', $value['content_type'], $value['nodetype'],
                                           $value['ref'], $value['weight'], $value['rid']);
    }
    else {
      // New rule.
      $result = db_query('INSERT INTO {panels_subsites_settings} (content_type, nodetype, ref, weight)
                          VALUES ("%s", "%s", "%s", %d)',
                          $value['content_type'], $value['nodetype'],
                          $value['ref'], $value['weight']);
    }
    if (!$result) {
      drupal_set_message(t('The settings have not been saved because of the database errors.'), 'error');
    }
  }

  drupal_set_message(t('The configuration options have been saved.'));
}